==> apache-arrow-datafusion-18.0.0.tar.gz: apache-arrow-datafusion-18.0.0/datafusion/expr/src/logical_plan/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

pub mod builder;
pub mod display;
mod extension;
mod plan;

pub use builder::{table_scan, LogicalPlanBuilder};
pub use plan::{
    Aggregate, Analyze, CreateCatalog, CreateCatalogSchema, CreateExternalTable,
    CreateMemoryTable, CreateView, CrossJoin, DescribeTable, Distinct, DmlStatement,
    DropTable, DropView, EmptyRelation, Explain, Extension, Filter, Join, JoinConstraint,
    JoinType, Limit, LogicalPlan, Partitioning, PlanType, PlanVisitor, Prepare,
    Projection, Repartition, SetVariable, Sort, StringifiedPlan, Subquery, SubqueryAlias,
    TableScan, ToStringifiedPlan, Union, Unnest, Values, Window, WriteOp,
};

pub use display::display_schema;

pub use extension::UserDefinedLogicalNode;

==> apache-arrow-datafusion-20.0.0.tar.gz: apache-arrow-datafusion-20.0.0/datafusion/expr/src/logical_plan/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

pub mod builder;
pub mod display;
mod extension;
mod plan;

pub use builder::{table_scan, LogicalPlanBuilder};
pub use plan::{
    Aggregate, Analyze, CreateCatalog, CreateCatalogSchema, CreateExternalTable,
    CreateMemoryTable, CreateView, CrossJoin, DescribeTable, Distinct, DmlStatement,
    DropTable, DropView, EmptyRelation, Explain, Extension, Filter, Join, JoinConstraint,
    JoinType, Limit, LogicalPlan, Partitioning, PlanType, PlanVisitor, Prepare,
    Projection, Repartition, SetVariable, Sort, StringifiedPlan, Subquery, SubqueryAlias,
    TableScan, ToStringifiedPlan, Union, Unnest, Values, Window, WriteOp,
};

pub use display::display_schema;

pub use extension::{UserDefinedLogicalNode, UserDefinedLogicalNodeCore};
